utils package - fastlob

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# utils package

## Submodules

## utils.utils module

Global utility functions.

fastlob.utils.utils.time_asint()

  int(time.time())

  Return type:

    `int`

fastlob.utils.utils.todecimal_price(price)

  Wrapper around the Decimal constructor to properly round numbers to user defined precision.

  Return type:

    `Decimal`

fastlob.utils.utils.todecimal_quantity(price)

  Wrapper around the Decimal constructor to properly round numbers to user defined precision.

  Return type:

    `Decimal`

fastlob.utils.utils.zero()

  Decimal(‘0’)

## Module contents

Global utility functions.